{% extends "layout.html" %}

{% block body %}
<h2>Stats</h2>
Musics: {{ stats.musics }}<br />
Artists: {{ stats.artists }}<br />
Albums: {{ stats.albums }}<br />
Genres: {{ stats.genres }}<br />
Keywords: {{ stats.keywords }}<br />
Size: {{ bytes_to_human(stats.size) }}<br />
Duration: {{ seconds_to_human(stats.duration) }}<br />
{% endblock %}
