{% extends "layout.html" %}
{% block title %}Generate{% endblock %}

{% block body %}
    <h2>Generate</h2>
<form method="GET" action="{{ url_for('collection.generate') }}">
    {{ form.csrf_token }}
    {#
    {{ form.min_rating.label }} {{ form.min_rating(size=1) }}<br>
    {{ form.max_rating.label }} {{ form.max_rating(size=1) }}<br>
    {{ form.min_size.label }} {{ form.min_size(size=10) }}<br>
    {{ form.max_size.label }} {{ form.max_size(size=10) }}<br>
    {{ form.min_duration.label }} {{ form.min_duration(size=10) }}<br>
    {{ form.max_duration.label }} {{ form.max_duration(size=10) }}<br>
    {{ form.limit.label }} {{ form.limit(size=10) }}<br>
    {{ form.youtube.label }} {{ form.youtube(size=1) }}<br>
    {{ form.shuffle.label }} {{ form.shuffle(size=1) }}<br>
    {{ form.formats.label }}<br> {{ form.formats(size=2) }}<br>
    {{ form.no_formats.label }}<br> {{ form.no_formats(size=2) }}<br>
    #}
    {{ form.genres.label }}<br> {{ form.genres(size=5) }}<br>
    {{ form.no_genres.label }}<br> {{ form.no_genres(size=5) }}<br>
    {{ form.artists.label }}<br> {{ form.artists(size=5) }}<br>
    {{ form.no_artists.label }}<br> {{ form.no_artists(size=5) }}<br>
    {{ form.keywords.label }}<br> {{ form.keywords(size=5) }}<br>
    {{ form.no_keywords.label }}<br> {{ form.no_keywords(size=5) }}<br>
    {{ form.titles.label }}<br> {{ form.titles(size=5) }}<br>
    {{ form.no_titles.label }}<br> {{ form.no_titles(size=5) }}<br>
    {{ form.albums.label }}<br> {{ form.albums(size=5) }}<br>
    {{ form.no_albums.label }}<br> {{ form.no_albums(size=5) }}<br>
    {{ form.form }} - {{ form.play }} - {{ form.zip }} - {{ form.m3u }}
</form>
{% endblock %}
