html {
  position: relative;
  min-height: 100%;
}

body {
  margin-bottom: 30px;
}

.container-music {
  margin-top: 60px;
}

.table-condensed>thead>tr>th, .table-condensed>tbody>tr>th, .table-condensed>tfoot>tr>th, .table-condensed>thead>tr>td, .table-condensed>tbody>tr>td, .table-condensed>tfoot>tr>td{
  padding: 0.1rem;
  font-size: 0.75rem;
}

#player {
  width: 100%;
}

audio {
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
}

ul#playlist li {
  padding-top: 0.25rem;
  padding-bottom: 0.25rem;
  font-size: 0.75rem;
}

ul#playlist li:hover {
  background:#333;
}

ul#playlist li.active a {
  color:#000000;
  text-decoration:none;
}

.footer {
  position: absolute;
  bottom: 0;
  width: 100%;
  height: 30px;
  line-height: 30px;
  background-color: #f5f5f5;
}
/*
#myProgress {
    width: 100%;
    background-color: grey;
}
#myBar {
    width: 1%;
    height: 30px;
    background-color: green;
}
*/
