<form name="mysearch" action="/collection/results" method="get" role="search">
  <input type="search" name="q" placeholder="search" id="search" required>
  <button type="submit" value="Submit">Search</button>
</form>
