{% extends "layout.html" %}
{% block title %}Filters{% endblock %}
{% block body %}
    <table class="table table-striped table-condensed">
      <thead class="thead-inverse">
        <tr>
          <th>Filter</th>
          <th>Diff</th>
          <th>Common</th>
          <th>Links</th>
          <th>Play</th>
        </tr>
      </thead>
      <tbody>
        {% for f in filters: %}
        <tr>
          <td>{{ f.name }}</td>
          <td>{{ f.diff() }}</td>
          <td>{{ f.common() }}</td>
          <td>
            <a href="{{ url_for('collection.musics', filter=f.name) }}">musics</a> /
            <a href="{{ url_for('collection.artists', filter=f.name) }}">artists</a> /
            <a href="{{ url_for('collection.albums', filter=f.name) }}">albums</a>
          </td>
          <td><a href="{{ url_for('collection.player', filter=f.name) }}">play</a></td>
        </tr>
        {% endfor %}
      </tbody>
    </table>
{% endblock %}
