# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['musicbot', 'musicbot.commands', 'musicbot.lib', 'musicbot.lib.web']

package_data = \
{'': ['*'], 'musicbot.lib.web': ['templates/*', 'templates/static/*']}

install_requires = \
['toml>=0.9,<0.10']

entry_points = \
{'console_scripts': ['musicbot = musicbot.musicbot:main']}

setup_kwargs = {
    'name': 'musicbot',
    'version': '0.0.1',
    'description': 'Music swiss knife, new gen.',
    'long_description': '========\nMusicBot\n========\n+---------------+-----------------+\n|     Tools     |      Result     |\n+===============+=================+\n|     Codacy    |    |codacy|     |\n+---------------+-----------------+\n|     Coverage  |   |coverage|    |\n+---------------+-----------------+\n\n.. |codacy| image:: https://api.codacy.com/project/badge/Grade/621acf3309b24c538c40824f9af467de\n   :target: https://www.codacy.com/app/AdrienPensart/musicbot?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=AdrienPensart/musicbot&amp;utm_campaign=Badge_Grade\n   :alt: Codacy badge\n.. |coverage| image:: https://github.com/AdrienPensart/musicbot/blob/master/doc/coverage.svg\n   :alt: Coverage badge\n\nDescription\n-----------\nCLI / API / Website to manipulate music and create smart playlists, and play it !\n\nInstallation\n------------\n\n.. code-block:: bash\n\n  git clone https://github.com/AdrienPensart/musicbot.git\n  cd musicbot\n  python-3.6 -m venv env\n  source env/bin/activate\n  pip install -r requirements.txt\nCommands\n--------\n.. code-block::\n\n  Usage: musicbot [OPTIONS] COMMAND [ARGS]...\n  \n    Music swiss knife, new gen.\n  \n  Options:\n    --version                       Show the version and exit.\n    --log PATH                      Log file path  [default:\n                                    /var/log/musicbot.log]\n    --debug                         Be very verbose, same as --verbosity debug +\n                                    hide progress bars\n    --timings                       Set verbosity to info and show execution\n                                    timings\n    --verbosity [debug|info|warning|error|critical]\n                                    Verbosity levels  [default: warning]\n    --dry                           Take no real action\n    --quiet                         Disable progress bars\n    --no-colors                     Disable colorized output\n    -h, --help                      Show this message and exit.\n  \n  Commands:\n    completion   Completion tool\n    config       Config management\n    consistency  Inconsistencies management\n    db           Database management\n    file         Music tags management\n    folder       Folder scanning\n    help         Print help\n    playlist     Playlist management\n    repl         Start an interactive shell.\n    server       API Server\n    stats        Youtube management\n    tag          Music tags management\n    task         Task management\n    youtube      Youtube management\n\n\nmusicbot completion\n*******************\n.. code-block::\n\n  Usage: musicbot completion [OPTIONS] COMMAND [ARGS]...\n  \n    Completion tool\n  \n  Options:\n    -h, --help  Show this message and exit.\n  \n  Commands:\n    help     Print help\n    install  Install the click-completion-command...\n    show     Show the click-completion-command completion...\n\n\nmusicbot completion help\n************************\n.. code-block::\n\n  Usage: musicbot completion help [OPTIONS] [COMMAND]...\n  \n    Print help\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot completion install\n***************************\n.. code-block::\n\n  Usage: musicbot completion install [OPTIONS] [SHELL] [PATH]\n  \n    Install the click-completion-command completion\n  \n  Options:\n    --append / --overwrite          Append the completion code to the file\n    -i, --case-insensitive / --no-case-insensitive\n                                    Case insensitive completion\n    -h, --help                      Show this message and exit.\n\n\nmusicbot completion show\n************************\n.. code-block::\n\n  Usage: musicbot completion show [OPTIONS] [SHELL]\n  \n    Show the click-completion-command completion code\n  \n  Options:\n    -i, --case-insensitive / --no-case-insensitive\n                                    Case insensitive completion\n    -h, --help                      Show this message and exit.\n\n\nmusicbot config\n***************\n.. code-block::\n\n  Usage: musicbot config [OPTIONS] COMMAND [ARGS]...\n  \n    Config management\n  \n  Options:\n    -h, --help  Show this message and exit.\n  \n  Commands:\n    help     Print help\n    logging  Show loggers tree\n    save     Save config\n    show     Print default config\n\n\nmusicbot config help\n********************\n.. code-block::\n\n  Usage: musicbot config help [OPTIONS] [COMMAND]...\n  \n    Print help\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot config logging\n***********************\n.. code-block::\n\n  Usage: musicbot config logging [OPTIONS]\n  \n    Show loggers tree\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot config save\n********************\n.. code-block::\n\n  Usage: musicbot config save [OPTIONS]\n  \n    Save config\n  \n  Options:\n    --redis-address TEXT    Redis URI  [default: redis://localhost]\n    --redis-db INTEGER      Redis index DB  [default: 0]\n    --redis-password TEXT   Redis password\n    --db-host TEXT          DB host  [default: localhost]\n    --db-port INTEGER       DB port  [default: 5432]\n    --db-database TEXT      DB name  [default: musicbot_prod]\n    --db-user TEXT          DB user  [default: postgres]\n    --db-password TEXT      DB password\n    --http-host TEXT        Host interface to listen on  [default: 127.0.0.1]\n    --http-server TEXT      Server name to use in links  [default: musicbot.ovh]\n    --http-port INTEGER     HTTP port to listen on  [default: 8000]\n    --http-workers INTEGER  Number of HTTP workers (not tested)  [default: 1]\n    --http-user TEXT        HTTP Basic auth user  [default: musicbot]\n    --http-password TEXT    HTTP Basic auth password\n    -h, --help              Show this message and exit.\n\n\nmusicbot config show\n********************\n.. code-block::\n\n  Usage: musicbot config show [OPTIONS]\n  \n    Print default config\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot consistency\n********************\n.. code-block::\n\n  Usage: musicbot consistency [OPTIONS] COMMAND [ARGS]...\n  \n    Inconsistencies management\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    errors  Detect errors\n    help    Print help\n\n\nmusicbot consistency errors\n***************************\n.. code-block::\n\n  Usage: musicbot consistency errors [OPTIONS]\n  \n    Detect errors\n  \n  Options:\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    -h, --help              Show this message and exit.\n\n\nmusicbot consistency help\n*************************\n.. code-block::\n\n  Usage: musicbot consistency help [OPTIONS] [COMMAND]...\n  \n    Print help\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot db\n***********\n.. code-block::\n\n  Usage: musicbot db [OPTIONS] COMMAND [ARGS]...\n  \n    Database management\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    clean    Clean deleted musics from database\n    clear    Drop and recreate database and schema\n    create   Create database and load schema\n    drop     Drop database schema\n    refresh  Refresh database materialized views\n\n\nmusicbot db clean\n*****************\n.. code-block::\n\n  Usage: musicbot db clean [OPTIONS]\n  \n    Clean deleted musics from database\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot db clear\n*****************\n.. code-block::\n\n  Usage: musicbot db clear [OPTIONS]\n  \n    Drop and recreate database and schema\n  \n  Options:\n    --yes       Are you sure you want to drop the db?\n    -h, --help  Show this message and exit.\n\n\nmusicbot db create\n******************\n.. code-block::\n\n  Usage: musicbot db create [OPTIONS]\n  \n    Create database and load schema\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot db drop\n****************\n.. code-block::\n\n  Usage: musicbot db drop [OPTIONS]\n  \n    Drop database schema\n  \n  Options:\n    --yes       Are you sure you want to drop the db?\n    -h, --help  Show this message and exit.\n\n\nmusicbot db refresh\n*******************\n.. code-block::\n\n  Usage: musicbot db refresh [OPTIONS]\n  \n    Refresh database materialized views\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot file\n*************\n.. code-block::\n\n  Usage: musicbot file [OPTIONS] COMMAND [ARGS]...\n  \n    Music tags management\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    help    Print help\n    show    Show tags of musics with filters\n    update\n\n\nmusicbot file help\n******************\n.. code-block::\n\n  Usage: musicbot file help [OPTIONS] [COMMAND]...\n  \n    Print help\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot file show\n******************\n.. code-block::\n\n  Usage: musicbot file show [OPTIONS]\n  \n    Show tags of musics with filters\n  \n  Options:\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    -h, --help              Show this message and exit.\n\n\nmusicbot file update\n********************\n.. code-block::\n\n  Usage: musicbot file update [OPTIONS]\n  \n  Options:\n    --keywords TEXT         Keywords\n    --artist TEXT           Artist\n    --album TEXT            Album\n    --title TEXT            Title\n    --genre TEXT            Genre\n    --number TEXT           Track number\n    --rating TEXT           Rating\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    -h, --help              Show this message and exit.\n\n\nmusicbot folder\n***************\n.. code-block::\n\n  Usage: musicbot folder [OPTIONS] COMMAND [ARGS]...\n  \n    Folder scanning\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    find      Only list files in selected folders\n    flac2mp3  Convert all files in folders to mp3\n    help      Print help\n    list      List existing folders\n    new       Add a new folder in database\n    rescan    Rescan all folders registered in database\n    scan      Load musics files in database\n    sync      Copy selected musics with filters to...\n    watch     Watch files changes in folders\n\n\nmusicbot folder find\n********************\n.. code-block::\n\n  Usage: musicbot folder find [OPTIONS] [FOLDERS]...\n  \n    Only list files in selected folders\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot folder flac2mp3\n************************\n.. code-block::\n\n  Usage: musicbot folder flac2mp3 [OPTIONS] [FOLDERS]...\n  \n    Convert all files in folders to mp3\n  \n  Options:\n    --concurrency INTEGER  Number of coroutines  [default: 8]\n    -h, --help             Show this message and exit.\n\n\nmusicbot folder help\n********************\n.. code-block::\n\n  Usage: musicbot folder help [OPTIONS] [COMMAND]...\n  \n    Print help\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot folder list\n********************\n.. code-block::\n\n  Usage: musicbot folder list [OPTIONS]\n  \n    List existing folders\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot folder new\n*******************\n.. code-block::\n\n  Usage: musicbot folder new [OPTIONS] [FOLDERS]...\n  \n    Add a new folder in database\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot folder rescan\n**********************\n.. code-block::\n\n  Usage: musicbot folder rescan [OPTIONS]\n  \n    Rescan all folders registered in database\n  \n  Options:\n    --crawl     Crawl youtube\n    -h, --help  Show this message and exit.\n\n\nmusicbot folder scan\n********************\n.. code-block::\n\n  Usage: musicbot folder scan [OPTIONS] [FOLDERS]...\n  \n    Load musics files in database\n  \n  Options:\n    --crawl     Crawl youtube\n    -h, --help  Show this message and exit.\n\n\nmusicbot folder sync\n********************\n.. code-block::\n\n  Usage: musicbot folder sync [OPTIONS] DESTINATION\n  \n    Copy selected musics with filters to destination folder\n  \n  Options:\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    -h, --help              Show this message and exit.\n\n\nmusicbot folder watch\n*********************\n.. code-block::\n\n  Usage: musicbot folder watch [OPTIONS]\n  \n    Watch files changes in folders\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot help\n*************\n.. code-block::\n\n  Usage: musicbot help [OPTIONS] [COMMAND]...\n  \n    Print help\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot playlist\n*****************\n.. code-block::\n\n  Usage: musicbot playlist [OPTIONS] COMMAND [ARGS]...\n  \n    Playlist management\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    bests  Generate bests playlists with some rules\n    help   Print help\n    new    Generate a new playlist\n\n\nmusicbot playlist bests\n***********************\n.. code-block::\n\n  Usage: musicbot playlist bests [OPTIONS] PATH\n  \n    Generate bests playlists with some rules\n  \n  Options:\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    --prefix TEXT           Append prefix before each path (implies relative)\n    --suffix TEXT           Append this suffix to playlist name\n    -h, --help              Show this message and exit.\n\n\nmusicbot playlist help\n**********************\n.. code-block::\n\n  Usage: musicbot playlist help [OPTIONS] [COMMAND]...\n  \n    Print help\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot playlist new\n*********************\n.. code-block::\n\n  Usage: musicbot playlist new [OPTIONS] [PATH]\n  \n    Generate a new playlist\n  \n  Options:\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    -h, --help              Show this message and exit.\n\n\nmusicbot repl\n*************\n.. code-block::\n\n  Usage: musicbot repl [OPTIONS]\n  \n    Start an interactive shell. All subcommands are available in it.\n  \n    :param old_ctx: The current Click context. :param prompt_kwargs:\n    Parameters passed to     :py:func:`prompt_toolkit.shortcuts.prompt`.\n  \n    If stdin is not a TTY, no prompt will be printed, but only commands read\n    from stdin.\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot server\n***************\n.. code-block::\n\n  Usage: musicbot server [OPTIONS] COMMAND [ARGS]...\n  \n    API Server\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    help   Print help\n    start  Start musicbot web API\n\n\nmusicbot server help\n********************\n.. code-block::\n\n  Usage: musicbot server help [OPTIONS] [COMMAND]...\n  \n    Print help\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot server start\n*********************\n.. code-block::\n\n  Usage: musicbot server start [OPTIONS]\n  \n    Start musicbot web API\n  \n  Options:\n    --http-host TEXT        Host interface to listen on  [default: 127.0.0.1]\n    --http-server TEXT      Server name to use in links  [default: musicbot.ovh]\n    --http-port INTEGER     HTTP port to listen on  [default: 8000]\n    --http-workers INTEGER  Number of HTTP workers (not tested)  [default: 1]\n    --http-user TEXT        HTTP Basic auth user  [default: musicbot]\n    --http-password TEXT    HTTP Basic auth password\n    --dev                   Watch for source file modification\n    --watcher               Watch for music file modification\n    --autoscan              Enable auto scan background job\n    --server-cache          Activate server cache system\n    --client-cache          Activate client cache system\n    --no-auth               Disable authentication system\n    -h, --help              Show this message and exit.\n\n\nmusicbot stats\n**************\n.. code-block::\n\n  Usage: musicbot stats [OPTIONS] COMMAND [ARGS]...\n  \n    Youtube management\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    show  Generate some stats for music collection with...\n\n\nmusicbot stats show\n*******************\n.. code-block::\n\n  Usage: musicbot stats show [OPTIONS]\n  \n    Generate some stats for music collection with filters\n  \n  Options:\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    -h, --help              Show this message and exit.\n\n\nmusicbot tag\n************\n.. code-block::\n\n  Usage: musicbot tag [OPTIONS] COMMAND [ARGS]...\n  \n    Music tags management\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    show  Show tags of musics with filters\n\n\nmusicbot tag show\n*****************\n.. code-block::\n\n  Usage: musicbot tag show [OPTIONS]\n  \n    Show tags of musics with filters\n  \n  Options:\n    --fields TEXT           Show only those fields\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    -h, --help              Show this message and exit.\n\n\nmusicbot task\n*************\n.. code-block::\n\n  Usage: musicbot task [OPTIONS] COMMAND [ARGS]...\n  \n    Task management\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    list  List tasks in database\n    new   Add a new task in database\n\n\nmusicbot task list\n******************\n.. code-block::\n\n  Usage: musicbot task list [OPTIONS]\n  \n    List tasks in database\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot task new\n*****************\n.. code-block::\n\n  Usage: musicbot task new [OPTIONS] NAME\n  \n    Add a new task in database\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\nmusicbot youtube\n****************\n.. code-block::\n\n  Usage: musicbot youtube [OPTIONS] COMMAND [ARGS]...\n  \n    Youtube management\n  \n  Options:\n    --db-host TEXT      DB host  [default: localhost]\n    --db-port INTEGER   DB port  [default: 5432]\n    --db-database TEXT  DB name  [default: musicbot_prod]\n    --db-user TEXT      DB user  [default: postgres]\n    --db-password TEXT  DB password\n    -h, --help          Show this message and exit.\n  \n  Commands:\n    albums  Fetch youtube links for each album\n    musics  Fetch youtube links for each music\n    only    Fetch youtube links for each album\n\n\nmusicbot youtube albums\n***********************\n.. code-block::\n\n  Usage: musicbot youtube albums [OPTIONS]\n  \n    Fetch youtube links for each album\n  \n  Options:\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    --concurrency INTEGER   Number of coroutines  [default: 8]\n    --youtube-album TEXT    Select albums with a youtube link\n    -h, --help              Show this message and exit.\n\n\nmusicbot youtube musics\n***********************\n.. code-block::\n\n  Usage: musicbot youtube musics [OPTIONS]\n  \n    Fetch youtube links for each music\n  \n  Options:\n    --limit INTEGER         Fetch a maximum limit of music\n    --youtubes TEXT         Select musics with a youtube link\n    --no-youtubes TEXT      Select musics without youtube link\n    --formats TEXT          Select musics with file format\n    --no-formats TEXT       Filter musics without format\n    --keywords TEXT         Select musics with keywords\n    --no-keywords TEXT      Filter musics without keywords\n    --artists TEXT          Select musics with artists\n    --no-artists TEXT       Filter musics without artists\n    --albums TEXT           Select musics with albums\n    --no-albums TEXT        Filter musics without albums\n    --titles TEXT           Select musics with titles\n    --no-titles TEXT        Filter musics without titless\n    --genres TEXT           Select musics with genres\n    --no-genres TEXT        Filter musics without genres\n    --min-duration INTEGER  Minimum duration filter (hours:minutes:seconds)\n    --max-duration INTEGER  Maximum duration filter (hours:minutes:seconds))\n    --min-size INTEGER      Minimum file size filter (in bytes)\n    --max-size INTEGER      Maximum file size filter (in bytes)\n    --min-rating FLOAT      Minimum rating  [default: 0.0]\n    --max-rating FLOAT      Maximum rating  [default: 5.0]\n    --relative              Generate relatives paths\n    --shuffle               Randomize selection\n    --concurrency INTEGER   Number of coroutines  [default: 8]\n    -h, --help              Show this message and exit.\n\n\nmusicbot youtube only\n*********************\n.. code-block::\n\n  Usage: musicbot youtube only [OPTIONS]\n  \n    Fetch youtube links for each album\n  \n  Options:\n    -h, --help  Show this message and exit.\n\n\n',
    'author': 'Adrien Pensart',
    'author_email': 'crunchengine@gmail.com',
    'url': 'https://github.com/AdrienPensart/musicbot',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<3.7',
}


setup(**setup_kwargs)
